A simple `Django <https://www.djangoproject.com/>`_ application for
showing information about software projects you maintain.

Support is included for listing projects, versions of projects, status
of each release, and associated metadata including licensing and the
location of packages/source code/documentation/contiuous integration.

Documentation is included and is also `available online
<http://django-project-portfolio.readthedocs.org/>`_.
